API
===


Classes
-------

.. currentmodule:: nikamap

.. autosummary::
   :template: class.rst
   :toctree: gen_api

   NikaBeam
   NikaMap
   Jackknife

Functions
---------

.. autosummary::
    :template: function.rst
    :toctree: gen_api

    bootstrap
    fake_data
